"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlanItemController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const loopback4_authorization_1 = require("loopback4-authorization");
const loopback4_authentication_1 = require("loopback4-authentication");
const permissions_1 = require("../permissions");
const core_1 = require("@sourceloop/core");
const basePath = '/plan-items';
let PlanItemController = class PlanItemController {
    constructor(planItemRepository) {
        this.planItemRepository = planItemRepository;
    }
    async create(planItem) {
        return this.planItemRepository.create(planItem);
    }
    async count(where) {
        return this.planItemRepository.count(where);
    }
    async find(filter) {
        return this.planItemRepository.find(filter);
    }
    async updateAll(planItem, where) {
        return this.planItemRepository.updateAll(planItem, where);
    }
    async findById(id, filter) {
        return this.planItemRepository.findById(id, filter);
    }
    async updateById(id, planItem) {
        await this.planItemRepository.updateById(id, planItem);
    }
    async replaceById(id, planItem) {
        await this.planItemRepository.replaceById(id, planItem);
    }
    async deleteById(id) {
        await this.planItemRepository.deleteById(id);
    }
};
exports.PlanItemController = PlanItemController;
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: [permissions_1.PermissionKey.CreatePlanItem],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.post)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'PlanItem  model instance',
                content: {
                    'application/json': { schema: (0, rest_1.getModelSchemaRef)(models_1.PlanItem) },
                },
            },
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.PlanItem, {
                    title: 'NewPlanItem',
                    exclude: ['id'],
                }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], PlanItemController.prototype, "create", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: [permissions_1.PermissionKey.ViewPlanItem],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.get)(`${basePath}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'PlanItem model count',
                content: { 'application/json': { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.where(models_1.PlanItem)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], PlanItemController.prototype, "count", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: [permissions_1.PermissionKey.ViewPlanItem],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.get)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Array of PlanItem model instances',
                content: {
                    'application/json': {
                        schema: {
                            type: 'array',
                            items: (0, rest_1.getModelSchemaRef)(models_1.PlanItem, { includeRelations: true }),
                        },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.filter(models_1.PlanItem)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], PlanItemController.prototype, "find", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: [permissions_1.PermissionKey.UpdatePlanItem],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.patch)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'PlanItem PATCH success count',
                content: { 'application/json': { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.PlanItem, { partial: true }),
            },
        },
    })),
    tslib_1.__param(1, rest_1.param.where(models_1.PlanItem)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.PlanItem, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], PlanItemController.prototype, "updateAll", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: [permissions_1.PermissionKey.ViewPlanItem],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.get)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'PlanItem  model instance',
                content: {
                    'application/json': {
                        schema: (0, rest_1.getModelSchemaRef)(models_1.PlanItem, { includeRelations: true }),
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.param.filter(models_1.PlanItem, { exclude: 'where' })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], PlanItemController.prototype, "findById", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: [permissions_1.PermissionKey.UpdatePlanItem],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.patch)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'PlanItem PATCH success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.PlanItem, { partial: true }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.PlanItem]),
    tslib_1.__metadata("design:returntype", Promise)
], PlanItemController.prototype, "updateById", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: [permissions_1.PermissionKey.UpdatePlanItem],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.put)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'PlanItem PUT success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, (0, rest_1.requestBody)()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.PlanItem]),
    tslib_1.__metadata("design:returntype", Promise)
], PlanItemController.prototype, "replaceById", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: [permissions_1.PermissionKey.DeletePlanItem],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.del)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'PlanItem DELETE success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String]),
    tslib_1.__metadata("design:returntype", Promise)
], PlanItemController.prototype, "deleteById", null);
exports.PlanItemController = PlanItemController = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.PlanItemRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.PlanItemRepository])
], PlanItemController);
//# sourceMappingURL=plan-item.controller.js.map